@@ -83,27 +83,44 @@ class JobThread(threading.Thread):
                         timeout=queue_tiemout, 
                         from_right=self.from_right
                         )
-            except ztq_core.ConnectionError:
-                print 'ERROR: Not connected the server\n'
-                task = None
+            except ztq_core.ConnectionError, e:
+                logger.error('ERROR: redis connection error: %s' % str(e))
                 time.sleep(3)
+                continue
+            except ztq_core.ResponseError, e:
+                logger.error('ERROR: redis response error: %s' % str(e))
+                time.sleep(3)
+                continue
+            except Exception, e:
+                logger.error('ERROR: redis unknown error: %s' % str(e))
+                time.sleep(3)
+                continue
 
             if task is None: 
                 # 没有后续任务了。执行batch_func
                 if run_job_index > 0:
                     run_job_index = 0
                     queue_tiemout = QUEUE_TIMEOUT
-                    batch_func()
+                    try:
+                        batch_func()
+                    except Exception, e:
+                        logger.error('ERROR: batch execution error: %s' % str(e))
                 continue
 
-            self.start_job(task)
+            try:
+                self.start_job(task)
+            except Exception, e:
+                logger.error('ERROR: job start error: %s' % str(e))
 
             if batch_size > 0: 
                 if run_job_index >= batch_size - 1:
                     # 完成了一批任务。执行batch_func
                     run_job_index = 0
                     queue_tiemout = QUEUE_TIMEOUT
-                    batch_func()
+                    try:
+                        batch_func()
+                    except Exception, e:
+                        logger.error('ERROR: batch execution error: %s' % str(e))
                 else:
                     run_job_index += 1
                     queue_tiemout = -1
@@ -136,7 +153,10 @@ class JobThread(threading.Thread):
         except Exception, e:
             reason = traceback.format_exception(*sys.exc_info())
             # 将错误信息记录到服务器
-            return_code = str(e.args[0]) if len(e.args) > 1 else 300
+            try:
+                return_code = str(e.args[0]) if len(e.args) > 1 else 300
+            except:
+                return_code = 300
             task['runtime']['return'] = return_code
             task['runtime']['reason'] = reason[-11:]
             task['runtime']['end'] = int( time.time() )
